# Generated by roxygen2: do not edit by hand

S3method(EZQC,EZbakRArrowData)
S3method(EZQC,EZbakRData)
S3method(EZQC,EZbakRFractions)
S3method(EstimateFractions,EZbakRArrowData)
S3method(EstimateFractions,EZbakRData)
S3method(EstimateMutRates,EZbakRArrowData)
S3method(EstimateMutRates,EZbakRData)
S3method(get_normalized_read_counts,EZbakRData)
S3method(get_normalized_read_counts,EZbakRFractions)
S3method(print,EZbakRArrowData)
S3method(print,EZbakRData)
export(AverageAndRegularize)
export(CompareParameters)
export(CorrectDropout)
export(DeconvolveFractions)
export(EZDynamics)
export(EZMAPlot)
export(EZQC)
export(EZSimulate)
export(EZVolcanoPlot)
export(EZbakRArrowData)
export(EZbakRData)
export(EZbakRFractions)
export(EZbakRKinetics)
export(EZget)
export(EZpcaPlot)
export(EstimateFractions)
export(EstimateIsoformFractions)
export(EstimateKinetics)
export(EstimateMutRates)
export(ImportIsoformQuant)
export(NormalizeForDropout)
export(SimpleSim)
export(SimulateIsoforms)
export(SimulateMultiCondition)
export(SimulateMultiLabel)
export(SimulateOneRep)
export(VectSimulateMultiLabel)
export(VisualizeDropout)
export(create_fraction_design)
export(get_normalized_read_counts)
import(arrow)
import(data.table)
import(ggplot2)
importFrom(magrittr,"%>%")
